==> MythicLib-1.0.5-sources.jar: cn/handyplus/lib/attribute/MythicLibUtil.java <==
package cn.handyplus.lib.attribute;

import cn.handyplus.lib.InitApi;
import cn.handyplus.lib.core.NumberUtil;
import cn.handyplus.lib.util.BaseUtil;
import io.lumine.mythic.lib.api.player.MMOPlayerData;
import io.lumine.mythic.lib.api.stat.StatInstance;
import io.lumine.mythic.lib.api.stat.StatMap;
import io.lumine.mythic.lib.api.stat.modifier.StatModifier;
import io.lumine.mythic.lib.player.modifier.ModifierType;
import org.bukkit.entity.Player;

import java.util.List;

/**
 * MythicLib支持
 *
 * @author handy
 * @since 1.0.3
 */
public class MythicLibUtil {

    private MythicLibUtil() {
    }

    /**
     * 给玩家添加属性
     *
     * @param player        玩家
     * @param attributeList 属性列表
     */
    protected static void addAttribute(Player player, List<String> attributeList) {
        MMOPlayerData playerData = MMOPlayerData.get(player.getUniqueId());
        for (String attribute : attributeList) {
            String[] split = attribute.split(":");
            String attributeName = split[0].trim();
            String attributeValue = split[1].trim();
            StatModifier experienceModifier = new StatModifier(InitApi.PLUGIN.getName(),
                    // 移除颜色代码 -转换_ 转大写
                    BaseUtil.stripColor(attributeName).toUpperCase().replace("-", "_"),
                    NumberUtil.isNumericToDouble(attributeValue, 0.00),
                    ModifierType.FLAT);
            experienceModifier.register(playerData);
        }
    }

    /**
     * 移除玩家属性
     *
     * @param player 玩家
     */
    protected static void removeAttribute(Player player) {
        MMOPlayerData playerData = MMOPlayerData.get(player.getUniqueId());
        StatMap statMap = playerData.getStatMap();
        for (StatInstance instance : statMap.getInstances()) {
            instance.removeIf(i -> i.equals(InitApi.PLUGIN.getName()));
        }
    }

}

==> MythicLib-1.1.3-sources.jar: cn/handyplus/lib/attribute/MythicLibUtil.java <==
package cn.handyplus.lib.attribute;

import cn.handyplus.lib.InitApi;
import cn.handyplus.lib.core.NumberUtil;
import cn.handyplus.lib.util.BaseUtil;
import io.lumine.mythic.lib.api.player.MMOPlayerData;
import io.lumine.mythic.lib.api.stat.StatInstance;
import io.lumine.mythic.lib.api.stat.StatMap;
import io.lumine.mythic.lib.api.stat.modifier.StatModifier;
import io.lumine.mythic.lib.player.modifier.ModifierType;
import org.bukkit.entity.Player;

import java.util.List;

/**
 * MythicLib支持
 *
 * @author handy
 * @since 1.0.3
 */
public class MythicLibUtil {

    private static Boolean IS_NEW_VERSION;

    private MythicLibUtil() {
    }

    /**
     * 给玩家添加属性
     *
     * @param player        玩家
     * @param attributeList 属性列表
     */
    protected static void addAttribute(Player player, List<String> attributeList) {
        MMOPlayerData playerData = MMOPlayerData.get(player.getUniqueId());
        for (String attribute : attributeList) {
            String[] split = attribute.split(":");
            String attributeName = split[0].trim();
            String attributeValue = split[1].trim();
            StatModifier experienceModifier = new StatModifier(InitApi.PLUGIN.getName(),
                    // 移除颜色代码 -转换_ 转大写
                    BaseUtil.stripColor(attributeName).toUpperCase().replace("-", "_"),
                    NumberUtil.isNumericToDouble(attributeValue, 0.00),
                    ModifierType.FLAT);
            experienceModifier.register(playerData);
        }
    }

    /**
     * 移除玩家属性
     *
     * @param player 玩家
     */
    protected static void removeAttribute(Player player) {
        MMOPlayerData playerData = MMOPlayerData.get(player.getUniqueId());
        StatMap statMap = playerData.getStatMap();
        for (StatInstance instance : statMap.getInstances()) {
            instance.removeIf(i -> i.equals(InitApi.PLUGIN.getName()));
        }
    }

    /**
     * 是否新版本
     *
     * @return true 是
     */
    protected static boolean isNewVersion() {
        if (IS_NEW_VERSION != null) {
            return IS_NEW_VERSION;
        }
        try {
            Class.forName("io.lumine.mythic.lib.api.player.MMOPlayerData");
            IS_NEW_VERSION = true;
        } catch (ClassNotFoundException e) {
            IS_NEW_VERSION = false;
        }
        return IS_NEW_VERSION;
    }

}
